@@ -65,48 +65,11 @@ class BootQEMU(Boot):
             return False
         if 'method' not in parameters:
             return False
-        if parameters['method'] != 'qemu':
-            return False
-        if parameters['method'] == 'monitor':
+        if parameters['method'] not in ['qemu', 'monitor']:
             return False
         return True
 
 
-class BootMonitorQemu(Boot):
-
-    compatibility = 4  # FIXME: change this to 5 and update test cases
-
-    def __init__(self, parent, parameters):
-        super(BootMonitorQemu, self).__init__(parent)
-        self.action = BootMonitoredQemu()
-        self.action.section = self.action_type
-        self.action.job = self.job
-        parent.add_action(self.action, parameters)
-
-    @classmethod
-    def accepts(cls, device, parameters):
-        if 'method' not in parameters:
-            return False
-        if 'qemu' not in device['actions']['boot']['methods']:
-            return False
-        if parameters['method'] != 'monitor':
-            return False
-        return True
-
-
-class BootMonitoredQemu(BootAction):
-
-    def __init__(self):
-        super(BootMonitoredQemu, self).__init__()
-        self.name = 'boot_image_monitor'
-        self.description = "boot monitored image with retry"
-        self.summary = "boot monitor with retry"
-
-    def populate(self, parameters):
-        self.internal_pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
-        self.internal_pipeline.add_action(BootQemuRetry())
-
-
 class BootQEMUImageAction(BootAction):
 
     def __init__(self):
@@ -118,11 +81,11 @@ class BootQEMUImageAction(BootAction):
     def populate(self, parameters):
         self.internal_pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
         self.internal_pipeline.add_action(BootQemuRetry())
-        # Add AutoLoginAction unconditionally as this action does nothing if
-        # the configuration does not contain 'auto_login'
-        self.internal_pipeline.add_action(AutoLoginAction())
-        self.internal_pipeline.add_action(ExpectShellSession())
-        self.internal_pipeline.add_action(ExportDeviceEnvironment())
+        if self.has_prompts(parameters):
+            self.internal_pipeline.add_action(AutoLoginAction())
+            if self.test_has_shell(parameters):
+                self.internal_pipeline.add_action(ExpectShellSession())
+                self.internal_pipeline.add_action(ExportDeviceEnvironment())
 
 
 class BootQemuRetry(RetryAction):
@@ -138,71 +101,6 @@ class BootQemuRetry(RetryAction):
         self.internal_pipeline.add_action(CallQemuAction())
 
 
-class MonitorQemuAction(Action):
-
-    def __init__(self):
-        super(MonitorQemuAction, self).__init__()
-        self.name = "monitor-qemu"
-        self.description = "monitor qemu to boot the image"
-        self.summary = "monitor qemu to boot the image"
-        self.sub_command = []
-
-    def validate(self):
-        super(MonitorQemuAction, self).validate()
-        try:
-            boot = self.job.device['actions']['boot']['methods']['qemu']
-            qemu_binary = which(boot['parameters']['command'])
-            self.sub_command = [qemu_binary]
-            self.sub_command.extend(boot['parameters'].get('options', []))
-        except AttributeError as exc:
-            raise InfrastructureError(exc)
-        except (KeyError, TypeError):
-            self.errors = "Invalid parameters for %s" % self.name
-        substitutions = {}
-        commands = []
-        for action in self.data['download_action'].keys():
-            if action == 'offset' or action == 'available_loops' or action == 'uefi':
-                continue
-            image_arg = self.data['download_action'][action].get('image_arg', None)
-            action_arg = self.data['download_action'][action].get('file', None)
-            if not image_arg or not action_arg:
-                self.errors = "Missing image_arg for %s. " % action
-                continue
-            substitutions["{%s}" % action] = action_arg
-            commands.append(image_arg)
-        self.sub_command.extend(substitute(commands, substitutions))
-        if not self.sub_command:
-            self.errors = "No QEMU command to execute"
-
-    def run(self, connection, args=None):
-        """
-        CommandRunner expects a pexpect.spawn connection which is the return value
-        of target.device.power_on executed by boot in the old dispatcher.
-
-        In the new pipeline, the pexpect.spawn is a ShellCommand and the
-        connection is a ShellSession. CommandRunner inside the ShellSession
-        turns the ShellCommand into a runner which the ShellSession uses via ShellSession.run()
-        to run commands issued *after* the device has booted.
-        pexpect.spawn is one of the raw_connection objects for a Connection class.
-        """
-        # initialise the first Connection object, a command line shell into the running QEMU.
-        self.logger.info("Boot command: %s", ' '.join(self.sub_command))
-        shell = ShellCommand(' '.join(self.sub_command), self.timeout, logger=self.logger)
-        if shell.exitstatus:
-            raise JobError("%s command exited %d: %s" % (self.sub_command, shell.exitstatus, shell.readlines()))
-        self.logger.debug("started a shell command")
-
-        shell_connection = ShellSession(self.job, shell)
-        shell_connection = super(MonitorQemuAction, self).run(shell_connection, args)
-
-        # FIXME: the shell needs to wait for something
-
-        # FIXME: tests with multiple boots need to be handled too.
-        self.data['boot-result'] = 'failed' if self.errors else 'success'
-        # FIXME: from here, go into the new test action.
-        return shell_connection
-
-
 class CallQemuAction(Action):
 
     def __init__(self):
@@ -215,7 +113,8 @@ class CallQemuAction(Action):
     def validate(self):
         super(CallQemuAction, self).validate()
         if self.parameters['method'] == 'qemu' and 'prompts' not in self.parameters:
-            self.errors = "Unable to identify boot prompts from job definition."
+            if self.test_has_shell(self.parameters):
+                self.errors = "Unable to identify boot prompts from job definition."
         try:
             boot = self.job.device['actions']['boot']['methods']['qemu']
             if 'parameters' not in boot or 'command' not in boot['parameters']:
@@ -234,20 +133,21 @@ class CallQemuAction(Action):
             self.errors = "Invalid parameters for %s" % self.name
         substitutions = {}
         commands = []
-        for action in self.data['download_action'].keys():
-            if action == 'offset' or action == 'available_loops' or action == 'uefi':
+        namespace = self.parameters.get('namespace', 'common')
+        for label in self.data[namespace]['download_action'].keys():
+            if label == 'offset' or label == 'available_loops' or label == 'uefi':
                 continue
-            image_arg = self.data['download_action'][action].get('image_arg', None)
-            action_arg = self.data['download_action'][action].get('file', None)
+            image_arg = self.get_namespace_data(action='download_action', label=label, key='image_arg')
+            action_arg = self.get_namespace_data(action='download_action', label=label, key='file')
             if not image_arg or not action_arg:
-                self.errors = "Missing image_arg for %s. " % action
+                self.errors = "Missing image_arg for %s. " % label
                 continue
-            substitutions["{%s}" % action] = action_arg
+            substitutions["{%s}" % label] = action_arg
             commands.append(image_arg)
         self.sub_command.extend(substitute(commands, substitutions))
         if not self.sub_command:
             self.errors = "No QEMU command to execute"
-        uefi_dir = self.get_common_data('image', 'uefi_dir')
+        uefi_dir = self.get_namespace_data(action='deployimages', label='image', key='uefi_dir')
         if uefi_dir:
             self.sub_command.extend(['-L', uefi_dir, '-monitor', 'none'])
 
@@ -263,7 +163,7 @@ class CallQemuAction(Action):
         pexpect.spawn is one of the raw_connection objects for a Connection class.
         """
         # initialise the first Connection object, a command line shell into the running QEMU.
-        guest = self.get_common_data('guest', 'filename')
+        guest = self.get_namespace_data(action='apply-overlay-guest', label='guest', key='filename')
         if guest:
             self.logger.info("Extending command line for qcow2 test overlay")
             # interface is ide by default in qemu
@@ -273,15 +173,15 @@ class CallQemuAction(Action):
             # push the mount operation to the test shell pre-command to be run
             # before the test shell tries to execute.
             shell_precommand_list = []
-            mountpoint = self.data['lava_test_results_dir']
-            uuid = '/dev/disk/by-uuid/%s' % self.get_common_data('guest', 'UUID')
+            mountpoint = self.get_namespace_data(action='test', label='results', key='lava_test_results_dir')
+            uuid = '/dev/disk/by-uuid/%s' % self.get_namespace_data(action='apply-overlay-guest', label='guest', key='UUID')
             shell_precommand_list.append('mkdir %s' % mountpoint)
             # prepare_guestfs always uses ext2
             shell_precommand_list.append('mount %s -t ext2 %s' % (uuid, mountpoint))
             # debug line to show the effect of the mount operation
             # also allows time for kernel messages from the mount operation to be processed.
             shell_precommand_list.append('ls -la %s/bin/lava-test-runner' % mountpoint)
-            self.set_common_data('lava-test-shell', 'pre-command-list', shell_precommand_list)
+            self.set_namespace_data(action='test', label='lava-test-shell', key='pre-command-list', value=shell_precommand_list)
 
         self.logger.info("Boot command: %s", ' '.join(self.sub_command))
         shell = ShellCommand(' '.join(self.sub_command), self.timeout, logger=self.logger)
@@ -295,7 +195,9 @@ class CallQemuAction(Action):
         shell_connection = super(CallQemuAction, self).run(shell_connection, args)
 
         # FIXME: tests with multiple boots need to be handled too.
-        self.data['boot-result'] = 'failed' if self.errors else 'success'
+        res = 'failed' if self.errors else 'success'
+        self.set_namespace_data(action='boot', label='shared', key='boot-result', value=res)
+        self.set_namespace_data(action='shared', label='shared', key='connection', value=shell_connection)
         return shell_connection
 
 
