@@ -22,6 +22,7 @@ import os
 import yaml
 
 from lava_dispatcher.pipeline.action import Action
+from lava_dispatcher.pipeline.utils.constants import LINE_SEPARATOR
 
 
 class DeployDeviceEnvironment(Action):
@@ -37,6 +38,7 @@ class DeployDeviceEnvironment(Action):
         self.env = ""
 
     def validate(self):
+        super(DeployDeviceEnvironment, self).validate()
         if 'lava_test_shell_file' not in \
            self.parameters['deployment_data'].keys():
             self.errors = "Invalid deployment data - missing lava_test_shell_file"
@@ -52,19 +54,30 @@ class DeployDeviceEnvironment(Action):
             self.env = self.job.parameters['env_dut']
             environment = self._create_environment()
 
-            self.set_common_data(
-                'environment',
-                'shell_file',
-                self.parameters['deployment_data']['lava_test_shell_file'])
+            self.set_namespace_data(
+                action=self.name,
+                label='environment',
+                key='shell_file',
+                value=self.parameters['deployment_data']['lava_test_shell_file']
+            )
 
-            self.set_common_data(
-                'environment',
-                'env_dict',
-                environment)
+            self.set_namespace_data(
+                action=self.name,
+                label='environment',
+                key='env_dict',
+                value=environment
+            )
 
         else:
             self.logger.info("no device environment specified")
 
+        self.set_namespace_data(
+            action=self.name,
+            label='environment',
+            key='line_separator',
+            value=self.parameters['deployment_data'].get('line_separator', LINE_SEPARATOR)
+        )
+
     def _create_environment(self):
         """Generate the env variables for the device."""
         conf = yaml.load(self.env) if self.env is not '' else {}
