@@ -47,6 +47,18 @@ class MultinodeTestShell(LavaTest):
                     return True
         return False
 
+    @classmethod
+    def needs_deployment_data(cls):
+        return True
+
+    @classmethod
+    def needs_overlay(cls):
+        return True
+
+    @classmethod
+    def has_shell(cls):
+        return True
+
 
 class MultinodeTestAction(TestShellAction):
 
