@@ -58,11 +58,23 @@ class PipelineDevice(dict):
             return self['commands']['soft_reset']
         return ''
 
+    @property
+    def pre_os_command(self):
+        if 'commands' in self and 'pre_os_command' in self['commands']:
+            return self['commands']['pre_os_command']
+        return None
+
+    @property
+    def pre_power_command(self):
+        if 'commands' in self and 'pre_power_command' in self['commands']:
+            return self['commands']['pre_power_command']
+        return None
+
     @property
     def power_command(self):
         if 'commands' in self and 'power_on' in self['commands']:
             return self['commands']['power_on']
-        return self.hard_reset_command
+        return ''
 
     @property
     def connect_command(self):
@@ -111,3 +123,10 @@ class NewDevice(PipelineDevice):
 
         self['hostname'] = self.target
         self.setdefault('power_state', 'off')  # assume power is off at start of job
+
+    def check_config(self, job):
+        """
+        Validates the combination of the job and the device
+        *before* the Deployment actions are initialised.
+        """
+        raise NotImplementedError("check_config")
